Module error

Module error 

Error types for Lie group and Lie algebra operations

Provides principled error handling for Lie-theoretic computations.

Structs

LogCondition
Conditioning information for logarithm computations.

Enums

LogError
Errors that can occur during Lie group logarithm computation
LogQuality
Quality levels for logarithm computations.
RepresentationError
Errors that can occur during representation theory computations

Type Aliases

ConditionedLogResult
Result type for conditioned logarithm operations.
LogResult
Result type for Lie group logarithm operations
RepresentationResult
Result type for representation theory operations